@@ -3,9 +3,9 @@ import shutil
 import tempo
 
 def make(path):
-	n=[i for i in path.split("/")]
+
 	empty('tempo.py')
-	file=open(n[-1],'r')
+	file=open(path,'r')
 	content=file.read()
 
 	fc=open('tempo.py','w')
